@@ -129,7 +129,8 @@ def create_merchant_customer_transaction_upstream_for_merchant(transaction_detai
     account_code        = merchant_acct.account_code.replace('-','')
     final_table_name    = '{}_{}_{}'.format(table_name, account_code, update_datetime.strftime('%Y%m%d'))
     
-    __create_upstream(transaction_details, CUSTOMER_TRANSACTION_TEMPLATE, MERCHANT_DATASET, final_table_name, update_datetime=update_datetime, Reverted=False, RevertedDateTime=None)
+    __create_upstream(transaction_details, CUSTOMER_TRANSACTION_TEMPLATE, MERCHANT_DATASET, final_table_name, 
+                      update_datetime=update_datetime, Reverted=False, RevertedDateTime=None)
 
 def create_merchant_customer_reward_upstream_for_merchant(transaction_details, reward_details, update_datetime=None):
     if update_datetime is None:
@@ -142,7 +143,8 @@ def create_merchant_customer_reward_upstream_for_merchant(transaction_details, r
     
     transaction_details_with_reward_details = CustomerTransactionWithRewardDetails(transaction_details, reward_details)
     
-    __create_upstream(transaction_details_with_reward_details, MERCHANT_CUSTOMER_REWARD_TEMPLATE, MERCHANT_DATASET, final_table_name, update_datetime=update_datetime)
+    __create_upstream(transaction_details_with_reward_details, MERCHANT_CUSTOMER_REWARD_TEMPLATE, MERCHANT_DATASET, final_table_name, 
+                      update_datetime=update_datetime, Reverted=False, RevertedDateTime=None)
 
 
 
